package net.crystalyx.sharewithtitle;

import org.jsoup.Jsoup;
import org.jsoup.nodes.Document;
import org.jsoup.nodes.Element;

import java.io.IOException;
import java.net.URL;

public class HttpThreadHandler implements Runnable {
    private final URL url;
    private String title;
    private String errorMessage;

    public HttpThreadHandler(URL url) {
        this.url = url;
    }

    @Override
    public void run() {
        try {
            Document doc = Jsoup.connect(url.toString()).get();
            String titleMeta = doc.title();
            Element descriptionMeta = doc.select("meta[name=description]").first();
            Element titleElement = doc.select("meta[property=og:title]").first();
            Element descriptionElement = doc.select("meta[property=og:description]").first();

            if (titleElement != null) {
                title = titleElement.attr("content");
                if (descriptionElement != null) {
                    title += "\n" + descriptionElement.attr("content");
                } else if (descriptionMeta != null) {
                    title += "\n" + descriptionMeta.attr("content");
                }
            } else {
                title = titleMeta;
                if (descriptionMeta != null) {
                    title += "\n" + descriptionMeta.attr("content");
                }
            }
        } catch (IOException e) {
            errorMessage = e.getMessage();
        }
    }

    public String getTitle() {
        return title;
    }

    public String getErrorMessage() {
        return errorMessage;
    }
}
